@@ -25,8 +25,9 @@ class AppEngine(Schedule):
                 "headers": {
                     "key": "User-Agent",
                     "value": "AppEngine-Google; (+http://code.google.com/appengine)"
-                }
+                },
+                "body": self.payload.encode()
             },
-            "schedule": self.cors,
+            "schedule": self.cron,
             "time_zone": "Europe/Amsterdam"
         }
