@@ -9,7 +9,7 @@ class PubSub(Schedule):
     Child class from Schedule contains the pub sub version
     """
 
-    topic_name: dict
+    topic_name: str
 
     def asdict(self, base_name, project):
         return {
@@ -17,8 +17,8 @@ class PubSub(Schedule):
             "description": self.description,
             "pubsub_target": {
                 "topic_name": f"projects/{project}/topics/{self.topic_name}",
-                "data": self.payload
+                "data": self.payload.encode()
             },
-            "schedule": self.cors,
+            "schedule": self.cron,
             "time_zone": "Europe/Amsterdam"
         }
